import logging.config
from clyde import Command, Option, ManualFormatter, mixin
from .metadata import version
from .project import create
from .settings import settings


class Program(Command):
    """Packgram main program.
    """

    # Public

    meta_formatter = ManualFormatter

    # Mixins

    @mixin
    def initiate_logging(self):
        logging.config.dictConfig(settings.logging_config)
        logger = logging.getLogger()
        if self.debug:
            logger.setLevel(logging.DEBUG)
        if self.verbose:
            logger.setLevel(logging.INFO)
        if self.quiet:
            logger.setLevel(logging.ERROR)

    @mixin(require='help')
    def print_help(self):
        print(self.meta_format('help'))
        exit()

    @mixin(require='version')
    def print_version(self):
        print('Packgram ' + version)
        exit()

    # Options

    debug = Option(
        action='store_true',
        flags=['-d', '--debug'],
        help='Enable debug mode.',
    )

    help = Option(
        action='store_true',
        flags=['-h', '--help'],
        help='Display this help message.',
    )

    quiet = Option(
        action='store_true',
        flags=['-q', '--quiet'],
        help='Enable quiet mode.',
    )

    verbose = Option(
        action='store_true',
        flags=['-v', '--verbose'],
        help='Enable verbose mode.',
    )

    version = Option(
        action='store_true',
        flags=['-V', '--version'],
        help='Display the program version.',
    )

    # Subcommands

    class init(Command):
        """Create packgram in current working directory.
        """

        # Public

        def __execute__(self):
            create(self.source, self.target, bootstrap=self.bootstrap)

        # Options

        bootstrap = Option(
            flags=['-b', '--bootstrap'],
            help='Shell command to bootstrap packgram.',
        )

        source = Option(
            flags=['-s', '--source'],
            help='Path to packgram sources.',
        )

        target = Option(
            flags=['-t', '--target'],
            help='Path where packgram will be created.',
        )


program = Program()
