import os
from run import DialogModule, RenderTask, NullTask


class BootstrapModule(DialogModule):

    # Meta

    meta_default_task = 'bootstrap'

    # Tasks

    bootstrap = NullTask(
        meta_require=[
            'update_filenames',
            'update_runfile',
        ],
    )

    def update_filenames(self):
        root = '.'
        for dirpath, dirnames, filenames in os.walk(root, topdown=False):
            for name in dirnames + filenames:
                new_name = self.render_string(name)
                if name != new_name:
                    path = os.path.join(dirpath, name)
                    new_path = os.path.join(dirpath, new_name)
                    os.rename(path, new_path)

    def update_runfile(self):
        path = 'runfile.py'
        content = self.render_file(path)
        self.write_file(path, content)

    render_string = RenderTask(
        mode='string',
    )

    render_file = RenderTask(
        mode='file',
    )

    def write_file(self, path, content):
        dirname = os.path.dirname(path)
        if dirname:
            os.makedirs(dirname, exist_ok=True)
        with open(path, 'w') as file:
            file.write(content)
